Install — Toyz 0.0.0 documentation

# Install

## Requirements

- Python 2.7 or later
- Tornado 4.0 or later
- passlib 1.6.2 or later (eventually this will be optional and only required for password protected toyz applications)
- numpy 1.5.1 or later

## Optional Requirements

- Highcharts 4.0 or higher
    - Required for interactive plots and charts
    - Download is free for personal or non-profit use and reasonably priced for commercial use

## Installing Toyz

The Toyz framework only needs to be installed on the machine acting as the server. This can be a local machine, remote server, or even remote super-computer (we are working on testing this on a blue-gene super computer at the University of Rochester at this time).

### Using pip

Toyz is registered in the Python Package Index (pypi) and will shortly have version 0.0 added. Check back for updates on when this is compelete.

### Installing from source

#### Obtaining the source code

Download the source code here on github, or by typing:

    git clone git://github.com/fred3m/toyz.git

#### Installing

To install Toyz from the source code navigate to the root directory of the source code and type:

    python setup.py install

Note

On unix systems you may be required to prepend ‘sudo‘ to your install command:

    sudo python setup.py install

As this is a new package, please let me know any problems you have had installing the source code so I can fix them or share steps needed to resolve them with other users. For bugs, please create an issue on github. For other comments or suggestions please create a post on our Google group